@@ -21,10 +21,8 @@ MARSSaic = function(MLEobj, output=c("AIC","AICc"), Options=list(nboot=1000, ret
   if(is.null(Options[["nboot"]])) Options$nboot = 1000
   if(is.null(Options[["return.logL.star"]])) Options$return.logL.star = FALSE
   if(is.null(Options[["silent"]])) Options$silent = FALSE
-  tmp = is.marssMLE(MLEobj)
-  if(!isTRUE(tmp)) {
-    if(!Options$silent) cat(tmp)
-    stop("Stopped in MARSSaic() due to problem(s) with the MLE object passed in.\n", call.=FALSE)
+  if(class(MLEobj)[1]!="marssMLE") {
+    stop("Stopped in MARSSaic(). An object of class marssMLE is required.\n", call.=FALSE)
     }
     
   if(is.null(MLEobj[["logLik"]])){
