@@ -6,7 +6,8 @@
 MARSSparamCIs = function(MLEobj, method="hessian", alpha=0.05, nboot=1000, silent=TRUE, hessian.fun="Harvey1989") {
   #this function expects a marssMLE object
   #it will add standard errors, biases, low/up CIs to MLEobj
-  if(!is.marssMLE(MLEobj)) stop("Stopped in MARSSparamCIs(). This function needs a valid marssMLE object.\n", call.=FALSE)
+  if(class(MLEobj)[1]!="marssMLE")
+    stop("Stopped in MARSSparamCIs(). This function needs a marssMLE object.\n", call.=FALSE)
 
     if(!(method %in% c("hessian","parametric","innovations"))) stop("Stopped in MARSSparamCIs(). Current methods are hessian, parametric, innovations.\n", call.=FALSE)
   if(!(hessian.fun %in% c("Harvey1989","fdHess","optim"))) stop("Stopped in MARSSparamCIs(). Available functions for computing the Hessian are Harvey1989, fdHess, and optim.\n", call.=FALSE)  
